@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
 =encoding utf-8
 
@@ -16,30 +16,32 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.28
+Version 0.29
 
 =head1 DESCRIPTION
 
-B<Greple> B<xlate> module find text blocks and replace them by the
-translated text.  Currently DeepL (F<deepl.pm>) and ChatGPT
+B<Greple> B<xlate> module find desired text blocks and replace them by
+the translated text.  Currently DeepL (F<deepl.pm>) and ChatGPT
 (F<gpt3.pm>) module are implemeted as a back-end engine.
 
-If you want to translate normal text blocks written in the L<pod>
-style, use B<greple> command with C<xlate::deepl> and C<perl> module
-like this:
+If you want to translate normal text blocks in a document written in
+the Perl's pod style, use B<greple> command with C<xlate::deepl> and
+C<perl> module like this:
 
     greple -Mxlate::deepl -Mperl --pod --re '^(\w.*\n)+' --all foo.pm
 
-Pattern C<^(\w.*\n)+> means consecutive lines starting with
-alpha-numeric letter.  This command show the area to be translated.
-Option B<--all> is used to produce entire text.
+In this command, pattern string C<^(\w.*\n)+> means consecutive lines
+starting with alpha-numeric letter.  This command show the area to be
+translated highlighted.  Option B<--all> is used to produce entire
+text.
 
 =for html <p>
 <img width="750" src="https://raw.githubusercontent.com/kaz-utashiro/App-Greple-xlate/main/images/select-area.png">
 </p>
 
-Then add C<--xlate> option to translate the selected area.  It will
-find and replace them by the B<deepl> command output.
+Then add C<--xlate> option to translate the selected area.  Then, it
+will find the desired sections and replace them by the B<deepl>
+command output.
 
 By default, original and translated text is printed in the "conflict
 marker" format compatible with L<git(1)>.  Using C<ifdef> format, you
@@ -111,7 +113,8 @@ Specify the output format for original and translated text.
 
 =item B<conflict>, B<cm>
 
-Print original and translated text in L<git(1)> conflict marker format.
+Original and converted text are printed in L<git(1)> conflict marker
+format.
 
     <<<<<<< ORIGINAL
     original text
@@ -125,7 +128,8 @@ You can recover the original file by next L<sed(1)> command.
 
 =item B<ifdef>
 
-Print original and translated text in L<cpp(1)> C<#ifdef> format.
+Original and converted text are printed in L<cpp(1)> C<#ifdef>
+format.
 
     #ifdef ORIGINAL
     original text
@@ -140,7 +144,8 @@ You can retrieve only Japanese text by the B<unifdef> command:
 
 =item B<space>
 
-Print original and translated text separated by single blank line.
+Original and converted text are printed separated by single blank
+line.
 
 =item B<xtxt>
 
@@ -265,6 +270,8 @@ L<App::Greple::xlate::deepl>
 
 L<App::Greple::xlate::gpt3>
 
+L<https://hub.docker.com/r/tecolicom/xlate>
+
 =over 7
 
 =item L<https://github.com/DeepLcom/deepl-python>
@@ -297,13 +304,31 @@ option.
 
 =back
 
+=head2 ARTICLES
+
+=over 2
+
+=item * L<https://qiita.com/kaz-utashiro/items/1c1a51a4591922e18250>
+
+Greple module to translate and replace only the necessary parts with DeepL API (in Japanese)
+
+=item * L<https://qiita.com/kaz-utashiro/items/a5e19736416ca183ecf6>
+
+Generating documents in 15 languages with DeepL API module (in Japanese)
+
+=item * L<https://qiita.com/kaz-utashiro/items/1b9e155d6ae0620ab4dd>
+
+Automatic translation Docker environment with DeepL API (in Japanese)
+
+=back
+
 =head1 AUTHOR
 
 Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright © 2023 Kazumasa Utashiro.
+Copyright © 2023-2024 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
